### Name: TimeDateClass
### Title: timeDate Class, Functions and Methods
### Aliases: TimeDateClass rulesFinCenter listFinCenter timeDate
###   timeDate-class timeCalendar timeSequence Sys.timeDate
###   timeLastDayInMonth timeNdayOnOrAfter timeNdayOnOrBefore
###   timeNthNdayInMonth timeLastNdayInMonth is.timeDate print.timeDate
###   summary.timeDate format.timeDate isWeekday isWeekend isBizday weekDay
###   [.timeDate +.timeDate -.timeDate Ops.timeDate diff.timeDate
###   difftimeDate c.timeDate rep.timeDate start.timeDate end.timeDate
###   modify.timeDate rev.timeDate as.character.timeDate
###   as.data.frame.timeDate as.POSIXct.timeDate julian.POSIXt
###   julian.timeDate atoms.timeDate months.timeDate
### Keywords: chron

### ** Examples

## SOURCE("fCalendar.23A-TimeDateClass")

## c -
   xmpCalendar("\nStart: Create Character Vectors > ") 
   dts = c("1989-09-28", "2001-01-15", "2004-08-30", "1990-02-09")
   tms = c(  "23:12:55",   "10:34:02",   "08:30:00",   "11:18:23")
   dts; tms
   
## timeDate -
   xmpCalendar("\nNext: Construct timeDate Object from Character Vector > ") 
   timeDate(dts, format = "%Y-%m-%d", FinCenter = "GMT" )
   timeDate(dts, format = "%Y-%m-%d", FinCenter = "Europe/Zurich") 
   timeDate(paste(dts, tms), format = "%Y-%m-%d %H:%M:%S", 
     zone = "GMT", FinCenter = "GMT")
   timeDate(paste(dts, tms), format = "%Y-%m-%d %H:%M:%S", 
     zone = "Europe/Zurich", FinCenter = "Europe/Zurich")
   timeDate(paste(dts, tms), format = "%Y-%m-%d %H:%M:%S", 
     zone = "GMT", FinCenter = "Europe/Zurich") 
    
## timeCalendar - 
   xmpCalendar("\nNext: Create a timeDate Object From Calendar Atoms > ")
   timeCalendar( m = c(9, 1, 8, 2), d = c(28, 15, 30, 9), 
     y = c(1989, 2001, 2004, 1990), FinCenter = "GMT") 
   timeCalendar(m = c(9, 1, 8, 2), d = c(28, 15, 30, 9), 
     y = c(1989, 2001, 2004, 1990), FinCenter = "Europe/Zurich")
   timeCalendar(h = c(9, 14), min = c(15, 23)) 
  
## timeSequence - 
   xmpCalendar("\nNext: Create a Regularly Spaced timeDate Objects > ")
   timeSequence(from = "2004-03-12", to = "2004-04-11", 
        format = "%Y-%m-%d", FinCenter = "GMT")  
   timeSequence(from = "2004-03-12", to = "2004-04-11", 
        format = "%Y-%m-%d", FinCenter = "Europe/Zurich")
   
## timeDate - 
   xmpCalendar("\nNext: Note, ISO and American Formats are Auto-Detected > ")
   timeDate("2004-12-11", FinCenter = "GMT")    
   timeDate("12/11/2004", FinCenter = "GMT")   
  
## SOURCE("fBasics.A0-SPlusCompatibility")
## SOURCE("fBasics.E1-TimeDateClass")
## SOURCE("fBasics.E2-TimeDatemethods")
## SOURCE("fBasics.Z1-BasicsTools")

## c -
   xmpCalendar("\nStart: Create Character Vectors > ") 
   dts = c("1989-09-28", "2001-01-15", "2004-08-30", "1990-02-09")
   tms = c(  "23:12:55",   "10:34:02",   "08:30:00",   "11:18:23")
   dts; tms
   
## "+/-" - 
   xmpCalendar("\nStart: Add One Day to a Given timeDate Object > ")
   GMT = timeDate(dts, FinCenter = "GMT")
   ZUR = timeDate(dts, FinCenter = "Europe/Zurich")
   GMT + 24*3600
   ZUR[2] - ZUR[1]
  
## "[" - 
   xmpCalendar("\nNext: Subsets from and Lops for timeDate Objects > ")
   GMT[GMT < GMT[2]]
   ZUR[ZUR < ZUR[3]] == ZUR[1:3]

## diff - 
   xmpCalendar("\nNext: Suitably Lagged and Iterated Differences > ")
   diff(GMT)
   diff(GMT, lag = 2)
   diff(GMT, lag = 1, diff = 2)
   difftimeDate(GMT[1:2], GMT[-(1:2)])
   
## c | rep - 
   xmpCalendar("\nNext: Concatenate and Replicate timeDate Objects > ") 
   c(GMT[1:2], ZUR[1:2])
   c(ZUR[1:2], GMT[1:2])
   rep(ZUR[2], times = 3)
   rep(ZUR[2:3], times = 2) 

## round | truncate -
   xmpCalendar("\nNext: Round and Truncate timeDate Objects > ")
   modify(GMT, "round", "days")
   modify(ZUR, "round", "days")
   modify(GMT, "trunc", "days")
   modify(ZUR, "trunc", "days")

## start | end | sort - 
   xmpCalendar("\nNext: Extract First/Last, Sort timeDate Objects > ")
   c(start(ZUR), end(ZUR))
   modify(ZUR, "sort") 

## as -
   xmpCalendar("\nNext: Convert timeDate Objects to Other Objects > ")
   as.character(ZUR)
   as.data.frame(ZUR)
   as.POSIXct(ZUR)
   
## julian - 
   xmpCalendar("\nNext: Julian Time in Days Since 1970-01-01 > ")
   julian(ZUR)  
   as.integer(julian(ZUR))
   julian(ZUR, "days")  
   as.integer(julian(ZUR, "days"))
    
## atoms - 
   xmpCalendar("\nNext: Atoms from a timeDate Object > ")
   atoms(ZUR)
   atoms(ZUR)[,3]
   atoms(ZUR)[, "d"] 



